@@ -369,9 +369,6 @@ void TransformFOTBuilder::documentType(const DocumentTypeNIC &nic)
     else 
       os() << " SYSTEM";
     if (nic.systemId.size()) {
-      if (nic.publicId.size()) {
-	os() << ' ';
-      }
       char quote = contains(nic.systemId, '"') ? '\'' : '"';
       os() << quote << nic.systemId << quote;
     }
@@ -385,16 +382,10 @@ void TransformFOTBuilder::attributes(const Vector<StringC> &atts)
   for (size_t i = 0; i < atts.size(); i += 2) {
     os() << SP_ << atts[i] << '=';
     const StringC &s = atts[i + 1];
-    char quoteChar = 0;
-
-    if (!contains(s, '&'))
-      if (!contains(s, '"'))
-        quoteChar = '"';
-      else if (!contains(s, '\''))
-        quoteChar = '\'';
-
-    if (quoteChar)
-      os() << quoteChar << s << quoteChar;
+    if (!contains(s, '"'))
+      os() << '"' << s << '"';
+    else if (!contains(s, '\''))
+      os() << '\'' << s << '\'';
     else {
       os() << '"';
       for (size_t j = 0; j < s.size(); j++) {
@@ -404,13 +395,6 @@ void TransformFOTBuilder::attributes(const Vector<StringC> &atts)
 	  else
 	    outputNumericCharRef(os(), '"');
 	}
-	else
-	if (s[j] == '&' ) {
-          if (xml_)
-            os() << "&amp;";
-	  else
-            outputNumericCharRef(os(), '&');
-	}
         else
           os().put(s[j]);
       }
